.. SPDX-FileCopyrightText: 2024 Anna <cyber@sysrq.in>
.. SPDX-License-Identifier: CC0-1.0

repology\_client.exceptions
===========================

repology\_client.exceptions
---------------------------

.. automodule:: repology_client.exceptions
   :members:

repology\_client.exceptions.resolve
-----------------------------------

.. automodule:: repology_client.exceptions.resolve
   :members:
